@@ -276,11 +276,10 @@ xfce_sm_client_class_init(XfceSMClientClass *klass)
                                            G_TYPE_FROM_CLASS(klass),
                                            G_SIGNAL_RUN_LAST,
                                            G_STRUCT_OFFSET(XfceSMClientClass,
-                                                           save_state_extended),
+                                                           save_state),
                                            NULL, NULL,
-                                           g_cclosure_marshal_VOID__BOOLEAN,
-                                           G_TYPE_NONE, 1,
-                                           G_TYPE_BOOLEAN);
+                                           g_cclosure_marshal_VOID__VOID,
+                                           G_TYPE_NONE, 0);
 
     /**
      * XfceSMClient::save-state-extended:
@@ -879,9 +878,12 @@ xfce_sm_client_handle_save_yourself(XfceSMClient *sm_client,
                                     gboolean do_save_state)
 {
     if(do_quit_requested
-       && g_signal_has_handler_pending(G_OBJECT(sm_client),
-                                       signals[SIG_QUIT_REQUESTED],
-                                       0, FALSE))
+       && (g_signal_has_handler_pending(G_OBJECT(sm_client),
+                                        signals[SIG_QUIT_REQUESTED],
+                                        0, FALSE)
+           || g_signal_has_handler_pending(G_OBJECT(sm_client),
+                                           signals[SIG_SAVE_STATE_EXTENDED],
+                                           0, FALSE)))
     {
         Status status;
 
@@ -2166,7 +2168,8 @@ xfce_sm_client_get_client_id(XfceSMClient *sm_client)
  * valid program identifier set (see xfce_sm_client_set_program())
  * and a valid client ID (see xfce_sm_client_get_client_id()).
  *
- * Returns: a file name string, owned by the object
+ * Returns: a file name string, owned by the object or %NULL if
+ *          the session client is disabled.
  **/
 G_CONST_RETURN gchar *
 xfce_sm_client_get_state_file(XfceSMClient *sm_client)
@@ -2176,11 +2179,12 @@ xfce_sm_client_get_state_file(XfceSMClient *sm_client)
 
     g_return_val_if_fail(XFCE_IS_SM_CLIENT(sm_client), NULL);
 
+    if(!sm_client->client_id)
+        return NULL;
+
     if(sm_client->state_file)
         return sm_client->state_file;
 
-    g_return_val_if_fail(sm_client->client_id, NULL);
-
     prgname = g_get_prgname();
     if(G_UNLIKELY(!prgname))
         prgname = "unknown";
